#read in the data on Buzzard Bay tern populations
bird.data<-read.csv("buzzard_bay2.csv",header=TRUE)

#plot both the total population size in the region and the local population size on Bird Island
plot(bird.data$year,bird.data$total_size,type="b",col="black",lty=1,xlab="Year",ylab="Population size")
lines(bird.data$year,bird.data$local_size,type="b",col="gray",lty=2)

#calculate change in population size between successive years for the 2 populations
l_total<-NULL;
l_local<-NULL;# create empty lists to store information

for (i in 1:(length(bird.data$year)-1)){
  l_total<-rbind(l_total,bird.data$total_size[i+1]/bird.data$total_size[i])
  l_local<-rbind(l_local,bird.data$local_size[i+1]/bird.data$local_size[i])
}

#plot change in population size as function of population size
plot(bird.data$total_size[1:(length(bird.data$year)-1)],l_total,type="p",lty=1,col="black",xlab="Population size",ylab="Population change per year",ylim=c(0.7,1.5))
lines(bird.data$local_size[1:(length(bird.data$year)-1)],l_local,type="p",lty=1,col="red")
legend("topright",c("Total","Bird Island"),lty=c(1,1),col=c("black","red"))

#calculate the best straight lines to fit the data sets
model.t<-lm(l_total~bird.data$total_size[1:(length(bird.data$year)-1)])
model.l<-lm(l_local~bird.data$local_size[1:(length(bird.data$year)-1)])

#plot the best straight lines
abline(model.t,col="black")
abline(model.l,col="red")

#obtain info on straight line fit (statistical significane, % variation explained by population size)
summary(model.t)
summary(model.l)